metertools.is_meter_with_equivalent_binary_representation
=========================================================

.. autofunction:: abjad.tools.metertools.is_meter_with_equivalent_binary_representation
